@@ -25,13 +25,16 @@ def pull():
     with open(f"{path}/skynix/config.json", "w", encoding="utf-8") as f:
         json.dump(params, f, indent=4)
     typer.echo("Done installing requirements")
+    typer.echo("#############################################")
+    typer.echo("Please install xfce4-terminal if you don't have it on your system")
     
 
 @cli.command()
 def run():
-    config = json.load(open(f"/home/{os.getlogin()}/skynix/config.json"))
+    user = os.getlogin()
+    config = json.load(open(f"/home/{user}/skynix/config.json"))
     python = config["python"]
-    os.system(f'cd /home/{os.getlogin()}/skynix && pipenv shell && python -u "/home/{os.getlogin()}/skynix/main.py"')
+    os.system(f"xfce4-terminal --drop-down -e '{python} -u '/home/{user}/skynix/main.py''")
 
 @cli.command()
 def config():
